<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Residential;

class ResidentialController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        return view('residential.home');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('residential.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validate($request, [
        'image' => 'required|mimes:jpeg,png,jpg,zip,pdf|max:51200',  
        'imagename' => 'required'
        ]);

        $image = $request->image;
        $image_new_name = time().$image->getClientOriginalName();
        $image->move('upload/residential', $image_new_name);

        $residential = Residential::create([
            'image' => 'upload/residential/'.$image_new_name,
            'imagename' => $request->imagename
        ]);
        return redirect()->route('residential.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show()
    {
        //

        $residentials = Residential::all();
        return view('residential.index')->with('residentials', $residentials);

    }

    public function display()
    {
        //
        $residentials = Residential::all();
        return view('signature')->with('residentials', $residentials);

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //  
        $residential = Residential::find($id);
        return view('residential.edit')->with('residential', $residential);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        $this->validate($request,[
            'imagename' => 'required'
        ]);

        $residential = Residential::find($id);
        if($request->hasFile('image'))
        {
            $image = $request->image;
            $image_new_name = time(). $image->getClientOriginalName();
            $image->move('upload/residential', $image_new_name);
            $residential->image = 'upload/residential/'.$image_new_name;
        }
        $residential->imagename = $request->imagename;

        $residential->save();
        return redirect()->route('residential.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //

        Residential::find($id)->delete();
        return redirect()->route('residential.index');

        
    }
}
